@@ -1,5 +1,5 @@
 /**************************************************************************
-*   Copyright (C) 2005-2015 by Oleksandr Shneyder                         *
+*   Copyright (C) 2005-2016 by Oleksandr Shneyder                         *
 *   o.shneyder@phoca-gmbh.de                                              *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
@@ -85,7 +85,7 @@ HttpBrokerClient::~HttpBrokerClient()
 void HttpBrokerClient::createSshConnection()
 {
     QUrl lurl ( config->brokerurl );
-    sshConnection=new SshMasterConnection (this, lurl.host(), lurl.port(22),false,
+    sshConnection=new SshMasterConnection (this, lurl.host(), lurl.port(22),mainWindow->getAcceptRSA(),
                                            config->brokerUser, config->brokerPass,config->brokerSshKey,config->brokerAutologin,
                                            config->brokerKrbLogin, false);
 
@@ -97,6 +97,8 @@ void HttpBrokerClient::createSshConnection()
     connect ( sshConnection, SIGNAL ( userAuthError ( QString ) ),this,SLOT ( slotSshUserAuthError ( QString ) ) );
     connect ( sshConnection, SIGNAL ( connectionError(QString,QString)), this,
               SLOT ( slotSshConnectionError ( QString,QString ) ) );
+    connect ( sshConnection, SIGNAL(ioErr(SshProcess*,QString,QString)), this,
+              SLOT(slotSshIoErr(SshProcess*,QString,QString)));
     sshConnection->start();
 }
 
@@ -668,3 +670,13 @@ QString HttpBrokerClient::getHexVal ( const QByteArray& ba )
     return val.join ( ":" );
 }
 
+void HttpBrokerClient::slotSshIoErr(SshProcess* caller, QString error, QString lastSessionError)
+{
+    x2goDebug<<"Brocker SSH Connection IO Error, reconnect session\n";
+    if ( sshConnection )
+    {
+        delete sshConnection;
+        sshConnection=0l;
+    }
+    createSshConnection();
+}
