@@ -1,5 +1,5 @@
 /**************************************************************************
-*   Copyright (C) 2005-2015 by Oleksandr Shneyder                         *
+*   Copyright (C) 2005-2016 by Oleksandr Shneyder                         *
 *   o.shneyder@phoca-gmbh.de                                              *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
@@ -518,6 +518,11 @@ public:
         return miniMode;
     }
 
+    bool getAcceptRSA()
+    {
+        return acceptRsa;
+    }
+
     QScrollArea* getUsersArea()
     {
         return users;
@@ -844,6 +849,8 @@ private:
     QString pulseRuntimeDir;
     QString pulseCookieArg;
     int pulsePort;
+    bool pulseNoRecord;
+
     int esdPort;
     bool maximizeProxyWin;
     int proxyWinWidth;
@@ -1146,6 +1153,7 @@ private slots:
     void slotStartNewBrokerSession ();
 #ifdef Q_OS_DARWIN
     void slotSetModMap();
+    void handle_xmodmap_error (QProcess &proc);
 private:
     QTimer* modMapTimer;
     QString kbMap;
