@@ -1,5 +1,5 @@
 /**************************************************************************
-*   Copyright (C) 2005-2015 by Oleksandr Shneyder                         *
+*   Copyright (C) 2005-2016 by Oleksandr Shneyder                         *
 *   o.shneyder@phoca-gmbh.de                                              *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
@@ -90,7 +90,8 @@ private:
 #ifdef Q_OS_LINUX
     QGroupBox *rdpBox;
     QRadioButton* rRdesktop;
-    QRadioButton* rXfreeRDP;
+    QRadioButton* rXfreeRDPOld;
+    QRadioButton* rXfreeRDPNew;
     QLineEdit* cmdLine;
     QLineEdit* params;
     QString server;
