@@ -1,5 +1,5 @@
 /**************************************************************************
-*   Copyright (C) 2005-2015 by Oleksandr Shneyder                         *
+*   Copyright (C) 2005-2016 by Oleksandr Shneyder                         *
 *   o.shneyder@phoca-gmbh.de                                              *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
@@ -55,6 +55,11 @@
 
 static bool isLibSshInited=false;
 
+const QString SshMasterConnection::challenge_auth_code_prompts_[] = {
+  "Verification code:",
+  "One-time password (OATH) for"
+};
+
 
 #ifdef Q_OS_WIN
 #include <QSettings>
@@ -543,7 +548,6 @@ void SshMasterConnection::run()
         tcpProxySocket = new QTcpSocket();
         tcpProxySocket->setProxy( *tcpNetworkProxy );
         tcpProxySocket->connectToHost(host, port);
-        proxysocket = tcpProxySocket->socketDescriptor();
         if (!tcpProxySocket->waitForConnected(30000))
         {
             QString message=tr ( "Cannot connect to proxy server." );
@@ -555,6 +559,7 @@ void SshMasterConnection::run()
             quit();
             return;
         }
+        proxysocket = tcpProxySocket->socketDescriptor();
 #ifdef DEBUG
         x2goDebug << "Created HTTP proxy socket: " << proxysocket << endl;
 #endif
@@ -866,7 +871,7 @@ bool SshMasterConnection::userChallengeAuth()
             x2goDebug<<"Prompt[0]: |"<<prompt<<"|"<<endl;
 #endif
             QString pr=prompt;
-            if(pr=="Password: ")
+            if(pr.startsWith ("Password:"))
             {
 #ifdef DEBUG
                 x2goDebug<<"Password request"<<endl;
@@ -874,8 +879,20 @@ bool SshMasterConnection::userChallengeAuth()
                 ssh_userauth_kbdint_setanswer(my_ssh_session,0,pass.toAscii());
                 return userChallengeAuth();
             }
-            if(pr=="Verification code: ")
-            {
+
+            bool has_challenge_auth_code_prompt = false;
+            const std::size_t challenge_auth_code_prompts_size = (sizeof (challenge_auth_code_prompts_)/sizeof (*challenge_auth_code_prompts_));
+
+            for (std::size_t i = 0; i < challenge_auth_code_prompts_size; ++i) {
+                x2goDebug << "Checking against known prompt #" << i << ": " << challenge_auth_code_prompts_[i] << endl;
+
+                if (pr.startsWith (challenge_auth_code_prompts_[i])) {
+                    has_challenge_auth_code_prompt = true;
+                    break;
+                }
+            }
+
+            if (has_challenge_auth_code_prompt) {
 #ifdef DEBUG
                 x2goDebug<<"Verification code request"<<endl;
 #endif
@@ -946,6 +963,8 @@ bool SshMasterConnection::userChallengeAuth()
 
 bool SshMasterConnection::userAuthWithPass()
 {
+    bool ret = false;
+
     // Populate the userauth_list
     ssh_userauth_none(my_ssh_session, NULL);
 
@@ -957,11 +976,19 @@ bool SshMasterConnection::userAuthWithPass()
         x2goDebug<<"Challenge authentication requested."<<endl;
 #endif
         challengeAuthPasswordAccepted=false;
-        return userChallengeAuth();
+        ret = userChallengeAuth();
     }
 
-    if (method & SSH_AUTH_METHOD_PASSWORD)
+    if (!ret) {
+        x2goDebug << "Challenge authentication failed. Trying password mechanism if available." << endl;
+    }
+
+    if ((!ret) && (method & SSH_AUTH_METHOD_PASSWORD))
     {
+        if (!ret) {
+            x2goDebug << "Password mechanism available. Continuing." << endl;
+        }
+
 #ifdef DEBUG
         x2goDebug<<"Password authentication requested."<<endl;
 #endif
@@ -973,12 +1000,13 @@ bool SshMasterConnection::userAuthWithPass()
 #ifdef DEBUG
             x2goDebug<<"userAuthWithPass failed:" <<err<<endl;
 #endif
-            return false;
         }
-        return true;
+        else {
+            ret = true;
+        }
     }
 
-    return false;
+    return (ret);
 }
 
 
@@ -1091,7 +1119,7 @@ bool SshMasterConnection::userAuthWithKey()
         return false;
     }
     ssh_public_key pubkey=publickey_from_privatekey(prkey);
-    if (!prkey)
+    if (!pubkey)
     {
 #ifdef DEBUG
         x2goDebug<<"Failed to get public key from private key."<<endl;
@@ -1151,7 +1179,7 @@ bool SshMasterConnection::userAuthKrb()
      * as there is no preceding "outer double quote" the whole argument
      * is wrapped in.
      */
-    QString shcmd = "bash -c 'echo \"X2GODATABEGIN:" + uuidStr + "\"; whoami; echo \"X2GODATAEND:" + uuidStr + "\";'";
+    QString shcmd = "bash -l -c 'echo \"X2GODATABEGIN:" + uuidStr + "\"; export TERM=\"dumb\"; whoami; echo \"X2GODATAEND:" + uuidStr + "\";'";
 
     QString local_cmd = "";
     QStringList local_args;
